@@ -66,6 +66,18 @@ def main(
     if query is not None:
         df = df.query(query).copy()
 
+    # handle grouping variable
+    if len(grouping_variable) > 0:
+        idx_list = df[list(grouping_variable)].dropna().index
+        df = df.loc[idx_list].copy()
+
+        groups = df[list(grouping_variable)].apply(lambda x: '\n'.join(x), axis=1)
+
+        grouping_variable = ', '.join(grouping_variable)
+        df[grouping_variable] = groups
+    else:
+        grouping_variable = None
+
     # quick overview
     pyskim.skim(df)
 
@@ -112,25 +124,30 @@ def main(
     fig.savefig(outdir / 'scatterplot.pdf', bbox_inches='tight', pad_inches=0)
 
     # plot job counts
-    tmp = (
-        df.sort_values('date')
-        .drop_duplicates(subset=['wildcards'])
-        .assign(date_hour=df['date'].dt.round('H'))
+    df['date_job_finished'] = df['date'] + df['duration'].apply(
+        lambda x: pd.Timedelta(seconds=x)
+    )
+
+    tmp = df.sort_values('date_job_finished').assign(
+        date_group=lambda x: x['date_job_finished'].dt.round('S')
     )
 
     if grouping_variable is None:
-        tmp_grp = tmp.groupby('date_hour').size()
+        tmp_grp = tmp.groupby('date_group').size()
     else:
         tmp_grp = (
-            tmp.groupby([grouping_variable, 'date_hour'])
+            tmp.groupby([grouping_variable, 'date_group'])
             .size()
             .reset_index()
-            .pivot(columns=[grouping_variable], index=['date_hour'])
+            .pivot(columns=[grouping_variable], index=['date_group'])
             .fillna(0)
         )
 
         tmp_grp.columns = tmp_grp.columns.droplevel(0)
 
+    tmp_grp.loc[tmp_grp.index.min() - pd.Timedelta(seconds=1)] = 0
+    tmp_grp.sort_index(inplace=True)
+
     df_jobcounts = tmp_grp.cumsum()
 
     fig, ax = plt.subplots(figsize=(8, 6))
